pub struct Options {
pub parser_install_directories: Vec<String>,
pub parser_aliases: BTreeMap<String, String>,
pub language_retrieval_patterns: Vec<SerializableRegex>,
pub valid_captures: HashMap<String, BTreeMap<String, String>>,
pub valid_predicates: BTreeMap<String, Predicate>,
pub valid_directives: BTreeMap<String, Predicate>,
pub diagnostic_options: DiagnosticOptions,
pub formatting_options: FormattingOptions,
pub supported_abi_versions: Option<RangeInclusive<u32>>,
}Expand description
Configuration options for the language server.
Fields
parser_install_directories: Vec<String>A list of strings representing directories to search for parsers, of the form
<lang>.(so|dll|dylib) or tree-sitter-<lang>.wasm.
Supports environment variable expansion of the form ${VAR}.
parser_aliases: BTreeMap<String, String>A map of parser aliases.
language_retrieval_patterns: Vec<SerializableRegex>A list of patterns to aid the LSP in finding a language, given a file path. Patterns must have one capture group which represents the language name. Ordered from highest to lowest precedence.
valid_captures: HashMap<String, BTreeMap<String, String>>A map from query file name to valid captures. Valid captures are represented as a map from
capture name (sans @) to a short (markdown format) description. Note that captures
prefixed with an underscore are always permissible.
valid_predicates: BTreeMap<String, Predicate>A map of predicate names (sans # and ?) to parameter specifications.
valid_directives: BTreeMap<String, Predicate>A map of directive names (sans # and !) to parameter specifications.
diagnostic_options: DiagnosticOptionsOptions related to diagnostics
formatting_options: FormattingOptionsOptions related to formatting
supported_abi_versions: Option<RangeInclusive<u32>>An inclusive range of ABI versions supported by your tool. The end of the range must be greater than or equal to the start.